@@ -127,7 +127,7 @@ class TestProp2PO:
         pounit = self.singleelement(pofile)
         print(repr(pofile.units[0].target))
         print(repr(pounit.source))
-        assert pounit.source == "Norsk bokm\u00E5l"
+        assert pounit.source == "Norsk bokm\u00e5l"
 
     def test_multiline_escaping(self):
         """Checks that multiline enties can be parsed."""
