@@ -16,12 +16,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the N'Ko language.
+"""
+This module represents the N'Ko language.
 
 .. seealso:: :wp:`N'Ko_language`
 """
 
-
 import re
 
 from translate.lang import common
