@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -17,12 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Vietnamese language.
-
-.. seealso:: http://en.wikipedia.org/wiki/Vietnamese_language
 """
+This module represents the Vietnamese language.
 
-from __future__ import unicode_literals
+.. seealso:: :wp:`Vietnamese_language`
+"""
 
 from translate.lang import common, fr
 
@@ -38,13 +36,14 @@ class vi(common.Common):
 
     @classmethod
     def punctranslate(cls, text):
-        """Implement some extra features for quotation marks.
+        """
+        Implement some extra features for quotation marks.
 
         Known shortcomings:
             - % and $ are not touched yet for fear of variables
             - Double spaces might be introduced
         """
-        text = super(cls, cls).punctranslate(text)
+        text = super().punctranslate(text)
         return fr.guillemets(text)
 
     mozilla_nplurals = 2
