@@ -21,7 +21,10 @@
 
 from lxml import etree
 
-from translate.misc.xml_helpers import setXMLspace
+from translate.misc.xml_helpers import (
+    safely_set_text,
+    setXMLspace,
+)
 from translate.storage import lisa
 from translate.storage.placeables import general
 
@@ -39,7 +42,7 @@ class RESXUnit(lisa.LISAunit):
         """Returns an xml Element setup with given parameters."""
         langset = etree.Element(self.namespaced(self.languageNode))
 
-        langset.text = text
+        safely_set_text(langset, text)
         return langset
 
     def _gettargetnode(self):
@@ -66,7 +69,7 @@ class RESXUnit(lisa.LISAunit):
             return
         targetnode = self._gettargetnode()
         targetnode.clear()
-        targetnode.text = target or ""
+        safely_set_text(targetnode, target or "")
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate "comment" tag."""
@@ -77,11 +80,13 @@ class RESXUnit(lisa.LISAunit):
         if position == "append":
             if current_notes.strip() in text_stripped:
                 # Don't add duplicate comments
-                note.text = text_stripped
+                safely_set_text(note, text_stripped)
             else:
-                note.text = "\n".join(filter(None, [current_notes, text_stripped]))
+                safely_set_text(
+                    note, "\n".join(filter(None, [current_notes, text_stripped]))
+                )
         else:
-            note.text = text_stripped
+            safely_set_text(note, text_stripped)
         if note.text:
             # Correct the indent of <comment> by updating the tail of
             # the preceding <value> element
