@@ -142,37 +142,37 @@ WF_FIELDNAMES_HEADER_DEFAULTS = {
 WF_ESCAPE_MAP = (
     ("&'26;", "\u0026"),  # & - Ampersand (must be first to prevent
     #     escaping of escapes)
-    ("&'82;", "\u201A"),  # ‚ - Single low-9 quotation mark
+    ("&'82;", "\u201a"),  # ‚ - Single low-9 quotation mark
     ("&'85;", "\u2026"),  # … - Elippsis
     ("&'91;", "\u2018"),  # ‘ - left single quotation mark
     ("&'92;", "\u2019"),  # ’ - right single quotation mark
-    ("&'93;", "\u201C"),  # “ - left double quotation mark
-    ("&'94;", "\u201D"),  # ” - right double quotation mark
+    ("&'93;", "\u201c"),  # “ - left double quotation mark
+    ("&'94;", "\u201d"),  # ” - right double quotation mark
     ("&'96;", "\u2013"),  # – - en dash (validate)
     ("&'97;", "\u2014"),  # — - em dash (validate)
     ("&'99;", "\u2122"),  # ™ - Trade mark
     # Windows only
-    ("&'A0;", "\u00A0"),  #   - Non breaking space
-    ("&'A9;", "\u00A9"),  # © - Copyright
-    ("&'AE;", "\u00AE"),  # ® - Registered
-    ("&'BC;", "\u00BC"),  # ¼
-    ("&'BD;", "\u00BD"),  # ½
-    ("&'BE;", "\u00BE"),  # ¾
+    ("&'A0;", "\u00a0"),  #   - Non breaking space
+    ("&'A9;", "\u00a9"),  # © - Copyright
+    ("&'AE;", "\u00ae"),  # ® - Registered
+    ("&'BC;", "\u00bc"),  # ¼
+    ("&'BD;", "\u00bd"),  # ½
+    ("&'BE;", "\u00be"),  # ¾
     # Mac only
-    ("&'A8;", "\u00AE"),  # ® - Registered
+    ("&'A8;", "\u00ae"),  # ® - Registered
     ("&'AA;", "\u2122"),  # ™ - Trade mark
-    ("&'C7;", "\u00AB"),  # « - Left-pointing double angle quotation mark
-    ("&'C8;", "\u00BB"),  # » - Right-pointing double angle quotation mark
+    ("&'C7;", "\u00ab"),  # « - Left-pointing double angle quotation mark
+    ("&'C8;", "\u00bb"),  # » - Right-pointing double angle quotation mark
     ("&'C9;", "\u2026"),  # … - Horizontal Elippsis
-    ("&'CA;", "\u00A0"),  #   - Non breaking space
+    ("&'CA;", "\u00a0"),  #   - Non breaking space
     ("&'D0;", "\u2013"),  # – - en dash (validate)
     ("&'D1;", "\u2014"),  # — - em dash (validate)
-    ("&'D2;", "\u201C"),  # “ - left double quotation mark
-    ("&'D3;", "\u201D"),  # ” - right double quotation mark
+    ("&'D2;", "\u201c"),  # “ - left double quotation mark
+    ("&'D3;", "\u201d"),  # ” - right double quotation mark
     ("&'D4;", "\u2018"),  # ‘ - left single quotation mark
     ("&'D5;", "\u2019"),  # ’ - right single quotation mark
-    ("&'E2;", "\u201A"),  # ‚ - Single low-9 quotation mark
-    ("&'E3;", "\u201E"),  # „ - Double low-9 quotation mark
+    ("&'E2;", "\u201a"),  # ‚ - Single low-9 quotation mark
+    ("&'E3;", "\u201e"),  # „ - Double low-9 quotation mark
     # Other markers
     # Soft-break - XXX creates a problem with roundtripping could
     # also be represented by \u2028
